/****************************************
 * Reception et affichage des donnees de capteurs
 * Module 12 entrees analogiques / 16 numeriques vers Midi
 * Interface-Z
 * Sensors data reception and display from
 * 12 analogical ways / 16 digital ways to Midi
 *****************************************/

// Importer la library the Midibus
// http://smallbutdigital.com/themidibus.php
import themidibus.*; 
MidiBus myBus; 
PFont policeperso;

void setup() {
  size(780, 600);
  smooth();
  noStroke();
  background(0);

  // Liste des peripheriques Midi disponibles sur l'ordinateur
  // Displaying Midi devices existing on the computer  
  MidiBus.list(); 

  // Ouverture de port (this, In, Out)
  // Choisir le numero du peripherique dans la liste
  // In et Out etant les numeros des peripheriques entrant et sortant
  // Open Midi port (this, In, Out)
  // Choose the appropriate Midi device from the list
  // In and Out being the corresponding In and Out devices
  myBus = new MidiBus(this, 0, -1);
  // -1 pour ne pas ouvrir ce port
  // -1 in order not to open this port

  policeperso = loadFont("AonCariCeltic-32.vlw");
  textFont(policeperso, 32);
}

// Reception des capteurs analogiques
// Receiving analogical sensors
int[] capteur = new int[12];
int numero;
int[][] registre = new int[12][10];

void controllerChange(int channel, int number, int value) {
  // Recoit les messages Midi de type Control Change
  // Rangement et tri dans un tableau
  // Receive Control Change messages
  // Order in an array
  if ((number >= 32) && (number <= 39)) {
    numero = number - 32;
    capteur[numero] = value;
  }
  if ((number >= 48) && (number <= 51)) {
    numero = number - 40;
    capteur[numero] = value;
  }
  println("Control Change : Canal "+channel+" Numero "+number+" Valeur "+capteur[numero]);

  // registre a decalage pour le premier capteur
  // register for the first sensor
  if ((numero >= 0) && (numero <= 11)) {
    for (int j =9; j>0; j = j-1) {
      registre[numero][j] = registre[numero][j-1];
    }
    // une fois la case 0 recopiee sur la case 1,
    // transferer la valeur nouvelle du capteur dans la case 0 du registre  
    registre[numero][0] = capteur[numero];
  }
}

// Reception des capteurs tout ou rien
// Receiving "all or nothing" sensors
int[] num = new int[16];
int pitchoun;

void noteOn(int channel, int pitch, int velocity) {
  // Receive a note On
  if ((pitch >= 0) && (pitch <=15)) {
    pitchoun = pitch;
    num[pitchoun] = velocity;
    println("Note On : Channel:"+channel+" Pitch "+pitch+" Velocity "+num[pitchoun]);
  }
}

void noteOff(int channel, int pitch, int velocity) {
  // Receive a note Off
  if ((pitch >= 0) && (pitch <=15)) {
    pitchoun = pitch;
    num[pitchoun] = velocity;
    println("Note Off : Channel:"+channel+" Pitch "+pitch+" Velocity "+num[pitchoun]);
  }
}


void draw() {
  background(0); 
  fill(255);
  text("12-Ana - Capteurs Analogiques", 40, 30);
  // Affichage de la valeur courante de chaque capteur
  // Displaying the most recent value of each sensor
  for (int k =0; k<4; k = k+1 ) {
    fill(190);
    text(k+1, 10+k*180, 70);
    fill(255);
    text(capteur[k], k*180 +10, 110);
  }

  for (int k =0; k<4; k = k+1 ) {
    fill(190);
    text(k+5, 10+k*180, 220);
    fill(255);
    text(capteur[k+4], k*180 +10, 260);
  }

  for (int k =0; k<4; k = k+1 ) {
    fill(190);
    text(k+9, 10+k*180, 370);
    fill(255);
    text(capteur[k+8], k*180 +10, 410);
  }

  // Affichage des 4 premiers capteurs
  // Displaying the first 4 sensors
  for (int k =0; k<4; k = k+1 ) {
    // Affichage de 10 sliders
    for (int i =0; i<=9; i = i+1 ) {
      fill(10, 10, 140);
      rect((k*180)+55 + (i*12), 40, 10, 128);
    }
    // Affichage d'un bloc clair dont la hauteur
    // depend de la valeur du capteur
    for (int j = 0; j<=9; j = j+1) {
      fill(110, 110, 240);
      rect((k*180)+55 + (j*12), 40 + 127 - registre[k][j], 10, registre[k][j]);
    }
  }

  for (int k =0; k<4; k = k+1 ) {
    // Affichage de 10 sliders
    for (int i =0; i<=9; i = i+1 ) {
      fill(10, 10, 140);
      rect((k*180)+55 + (i*12), 190, 10, 128);
    }
    // Affichage d'un bloc clair dont la hauteur
    // depend de la valeur du capteur
    for (int j = 0; j<=9; j = j+1) {
      fill(110, 110, 240);
      rect((k*180)+55 + (j*12), 190 + 127 - registre[k+4][j], 10, registre[k+4][j]);
    }
  }

  for (int k =0; k<4; k = k+1 ) {
    // Affichage de 10 sliders
    for (int i =0; i<=9; i = i+1 ) {
      fill(134, 10, 88);
      rect((k*180)+55 + (i*12), 340, 10, 128);
    }
    // Affichage d'un bloc clair dont la hauteur
    // depend de la valeur du capteur
    for (int j = 0; j<=9; j = j+1) {
      fill(234, 110, 188);
      rect((k*180)+55 + (j*12), 340 + 127 - registre[k+8][j], 10, registre[k+8][j]);
    }
  }

  fill(255);
  text("Interrupteurs", 40, 540);

  // Affichage des interrupteurs
  // Displaying On/Off sensors
  for (int i =0; i<=7; i = i+1 ) {
    fill(10, 10, 140);
    rect(300 + (i*22), 520, 20, 20);
  }
  for (int j = 0; j<=7; j = j+1) {
    fill(110, 110, 240, num[j]*2);
    rect(302 + (j*22), 522, 16, 16);
  }
  for (int i =8; i<=15; i = i+1 ) {
    fill(134, 10, 88);
    rect(360 + (i*22), 520, 20, 20);
  }
  for (int j = 8; j<=15; j = j+1) {
    fill(234, 110, 188, num[j]*2);
    rect(362 + (j*22), 522, 16, 16);
  }
}

